# Self-Built Software Discovery
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#introduction)
  * [Benefits](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#benefits)
  * [Getting Started with Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#getting-started-with-self-built-software-discovery)
  * [Self-Built Software Agent](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#self-built-software-agent)
  * [Modeling Guidelines for Self-Built Software](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#modeling-guidelines-for-self-built-software)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#best-practices)
  * [Antipatterns](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#antipatterns)
  * [Alternative Approach to Modeling Self-Built Software](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#alternative-approach-to-modeling-self-built-software)
  * [Detailed Guides](https://help.sap.com/docs/leanix/ea/self-built-software-discovery#detailed-guides)


SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.
